# kule-ko
The billionth package for terminal colors!

## Basic Use
First, do 
```python
import kule-ko as k
```
to put the uh... You know. Package in your program?

To color text, it's as simple as calling a variable.
```python
print(f"{k.R}Hello world!{k.RESET})
```
This will cause the print to appear red.
There are some other functions too, probably.
```python
k.clear()
````
will clear the screen.
